@@ -585,6 +585,14 @@ func mapPageOn(vu moduleVU, p *common.Page) func(common.PageOnEventName, sobek.C
 				init: prepK6BrowserRegExChecker(rt),
 				wait: true,
 			},
+			common.EventPageRequestCalled: {
+				mapp: mapRequestEvent,
+				wait: false,
+			},
+			common.EventPageResponseCalled: {
+				mapp: mapResponseEvent,
+				wait: false,
+			},
 		}
 		pageOnEvent, ok := pageOnEvents[eventName]
 		if !ok {
