@@ -8,6 +8,7 @@ import (
 	"testing"
 	"time"
 
+	"go.k6.io/k6/internal/build"
 	"go.k6.io/k6/internal/lib/testutils"
 
 	"github.com/stretchr/testify/assert"
@@ -15,7 +16,6 @@ import (
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/consts"
 	"go.k6.io/k6/lib/fsext"
 	"go.k6.io/k6/lib/types"
 )
@@ -484,7 +484,7 @@ func TestArchiveRoundTripExecutorConfig(t *testing.T) {
 	}
 	arc1 := &lib.Archive{
 		Type:      "js",
-		K6Version: consts.Version,
+		K6Version: build.Version,
 		Options: lib.Options{
 			Scenarios: map[string]lib.ExecutorConfig{
 				"const-vus": execCfg,
